Kiwii
=====

* * *

Kiwi (/ˈkiːwi/ KEE-wee) or kiwis are flightless birds native to New Zealand, in the genus Apteryx and family Apterygidae. Approximately the size of a domestic chicken, kiwi are by far the smallest living ratites (which also consist of ostriches, emus, rheas, and cassowaries).

`kiwii`, on the other hand, is a home IOT ecosystem.